#####
Types
#####

Here is list of all available API types:


Available types
===============

.. toctree::
    :maxdepth: 1

    accepted_gift_types
    animation
    audio
    background_fill
    background_fill_freeform_gradient
    background_fill_gradient
    background_fill_solid
    background_type
    background_type_chat_theme
    background_type_fill
    background_type_pattern
    background_type_wallpaper
    birthdate
    bot_command
    bot_command_scope
    bot_command_scope_all_chat_administrators
    bot_command_scope_all_group_chats
    bot_command_scope_all_private_chats
    bot_command_scope_chat
    bot_command_scope_chat_administrators
    bot_command_scope_chat_member
    bot_command_scope_default
    bot_description
    bot_name
    bot_short_description
    business_bot_rights
    business_connection
    business_intro
    business_location
    business_messages_deleted
    business_opening_hours
    business_opening_hours_interval
    callback_query
    chat
    chat_administrator_rights
    chat_background
    chat_boost
    chat_boost_added
    chat_boost_removed
    chat_boost_source
    chat_boost_source_gift_code
    chat_boost_source_giveaway
    chat_boost_source_premium
    chat_boost_updated
    chat_full_info
    chat_invite_link
    chat_join_request
    chat_location
    chat_member
    chat_member_administrator
    chat_member_banned
    chat_member_left
    chat_member_member
    chat_member_owner
    chat_member_restricted
    chat_member_updated
    chat_permissions
    chat_photo
    chat_shared
    checklist
    checklist_task
    checklist_tasks_added
    checklist_tasks_done
    contact
    copy_text_button
    dice
    direct_message_price_changed
    direct_messages_topic
    document
    external_reply_info
    file
    force_reply
    forum_topic
    forum_topic_closed
    forum_topic_created
    forum_topic_edited
    forum_topic_reopened
    general_forum_topic_hidden
    general_forum_topic_unhidden
    gift
    gift_background
    gift_info
    gifts
    giveaway
    giveaway_completed
    giveaway_created
    giveaway_winners
    inaccessible_message
    inline_keyboard_button
    inline_keyboard_markup
    input_checklist
    input_checklist_task
    input_file
    input_media
    input_media_animation
    input_media_audio
    input_media_document
    input_media_photo
    input_media_video
    input_paid_media
    input_paid_media_photo
    input_paid_media_video
    input_poll_option
    input_profile_photo
    input_profile_photo_animated
    input_profile_photo_static
    input_story_content
    input_story_content_photo
    input_story_content_video
    keyboard_button
    keyboard_button_poll_type
    keyboard_button_request_chat
    keyboard_button_request_user
    keyboard_button_request_users
    link_preview_options
    location
    location_address
    login_url
    maybe_inaccessible_message
    menu_button
    menu_button_commands
    menu_button_default
    menu_button_web_app
    message
    message_auto_delete_timer_changed
    message_entity
    message_id
    message_origin
    message_origin_channel
    message_origin_chat
    message_origin_hidden_user
    message_origin_user
    message_reaction_count_updated
    message_reaction_updated
    owned_gift
    owned_gift_regular
    owned_gift_unique
    owned_gifts
    paid_media
    paid_media_info
    paid_media_photo
    paid_media_preview
    paid_media_video
    paid_message_price_changed
    photo_size
    poll
    poll_answer
    poll_option
    proximity_alert_triggered
    reaction_count
    reaction_type
    reaction_type_custom_emoji
    reaction_type_emoji
    reaction_type_paid
    reply_keyboard_markup
    reply_keyboard_remove
    reply_parameters
    response_parameters
    shared_user
    star_amount
    story
    story_area
    story_area_position
    story_area_type
    story_area_type_link
    story_area_type_location
    story_area_type_suggested_reaction
    story_area_type_unique_gift
    story_area_type_weather
    suggested_post_approval_failed
    suggested_post_approved
    suggested_post_declined
    suggested_post_info
    suggested_post_paid
    suggested_post_parameters
    suggested_post_price
    suggested_post_refunded
    switch_inline_query_chosen_chat
    text_quote
    unique_gift
    unique_gift_backdrop
    unique_gift_backdrop_colors
    unique_gift_colors
    unique_gift_info
    unique_gift_model
    unique_gift_symbol
    user
    user_chat_boosts
    user_profile_photos
    user_rating
    user_shared
    users_shared
    venue
    video
    video_chat_ended
    video_chat_participants_invited
    video_chat_scheduled
    video_chat_started
    video_note
    voice
    web_app_data
    web_app_info
    write_access_allowed

Inline mode
===========

.. toctree::
    :maxdepth: 1

    chosen_inline_result
    inline_query
    inline_query_result
    inline_query_result_article
    inline_query_result_audio
    inline_query_result_cached_audio
    inline_query_result_cached_document
    inline_query_result_cached_gif
    inline_query_result_cached_mpeg4_gif
    inline_query_result_cached_photo
    inline_query_result_cached_sticker
    inline_query_result_cached_video
    inline_query_result_cached_voice
    inline_query_result_contact
    inline_query_result_document
    inline_query_result_game
    inline_query_result_gif
    inline_query_result_location
    inline_query_result_mpeg4_gif
    inline_query_result_photo
    inline_query_result_venue
    inline_query_result_video
    inline_query_result_voice
    inline_query_results_button
    input_contact_message_content
    input_invoice_message_content
    input_location_message_content
    input_message_content
    input_text_message_content
    input_venue_message_content
    prepared_inline_message
    sent_web_app_message

Payments
========

.. toctree::
    :maxdepth: 1

    affiliate_info
    invoice
    labeled_price
    order_info
    paid_media_purchased
    pre_checkout_query
    refunded_payment
    revenue_withdrawal_state
    revenue_withdrawal_state_failed
    revenue_withdrawal_state_pending
    revenue_withdrawal_state_succeeded
    shipping_address
    shipping_option
    shipping_query
    star_transaction
    star_transactions
    successful_payment
    transaction_partner
    transaction_partner_affiliate_program
    transaction_partner_chat
    transaction_partner_fragment
    transaction_partner_other
    transaction_partner_telegram_ads
    transaction_partner_telegram_api
    transaction_partner_user

Stickers
========

.. toctree::
    :maxdepth: 1

    input_sticker
    mask_position
    sticker
    sticker_set

Telegram Passport
=================

.. toctree::
    :maxdepth: 1

    encrypted_credentials
    encrypted_passport_element
    passport_data
    passport_element_error
    passport_element_error_data_field
    passport_element_error_file
    passport_element_error_files
    passport_element_error_front_side
    passport_element_error_reverse_side
    passport_element_error_selfie
    passport_element_error_translation_file
    passport_element_error_translation_files
    passport_element_error_unspecified
    passport_file

Getting updates
===============

.. toctree::
    :maxdepth: 1

    update
    webhook_info

Games
=====

.. toctree::
    :maxdepth: 1

    callback_game
    game
    game_high_score
